@@ -11,13 +11,29 @@ use URI;
 use String::ShellQuote;
 
 my $app = 'eg/dot-psgi/Hello.psgi';
-my $ab  = 'ab -n 100 -c 10 -k';
+my $ab  = 'ab -t 1 -c 10 -k';
 my $url = 'http://127.0.0.1/';
 
-my @backends = grep eval "require Plack::Server::$_; 1",
-    qw( AnyEvent Standalone Standalone::Prefork ServerSimple Coro Danga::Socket POE );
+my @try = (
+    [ 'AnyEvent::HTTPD' ],
+    [ 'HTTP::Server::PSGI' ],
+    [ 'HTTP::Server::PSGI', ' (workers=10)', max_workers => 10 ],
+    [ 'Twiggy' ],
+    [ 'HTTP::Server::Simple' ],
+    [ 'Coro' ],
+    [ 'Danga::Socket' ],
+    [ 'POE' ],
+    [ 'Starman', ' (workers=10)', workers => 10 ],
+);
 
-warn "Testing implementations: ", join(", ", @backends), "\n";
+my @backends;
+
+for my $handler (@try) {
+    eval { Plack::Loader->load($handler->[0]) };
+    push @backends, $handler unless $@;
+}
+
+warn "Testing implementations: ", join(", ", map $_->[0], @backends), "\n";
 
 GetOptions(
     'a|app=s'   => \$app,
@@ -34,14 +50,14 @@ ab:  $ab
 URL: $url
 
 EOF
-    for my $server_class (@backends) {
-        run_one($server_class);
+    for my $handler (@backends) {
+        run_one(@$handler);
     }
 }
 
 sub run_one {
-    my $server_class = shift;
-    print "-- server: $server_class\n";
+    my($server_class, $how, @args) = @_;
+    print "-- server: $server_class ", ($how || ''), "\n";
 
     test_tcp(
         client => sub {
@@ -49,12 +65,13 @@ sub run_one {
             my $uri = URI->new($url);
             $uri->port($port);
             $uri = shell_quote($uri);
+            system "ab -n 20 $uri > /dev/null"; # warmup
             print `$ab $uri | grep 'Requests per '`;
         },
         server => sub {
             my $port = shift;
             my $handler = Plack::Util::load_psgi $app;
-            my $server = Plack::Loader->load($server_class, port => $port);
+            my $server = Plack::Loader->load($server_class, port => $port, @args);
             $server->run($handler);
         },
     );
